from typing import Union, Iterable
import asf_search.search

def product_search(
        product_list: Iterable[str],
        host: str = asf_search.INTERNAL.HOST,
        output: str = 'geojson'
) -> dict:
    """
    Performs a product ID search using the ASF SearchAPI

    :param product_list: List of specific products. Results guaranteed to be at most one product per product name.
    :param host: SearchAPI host, defaults to Production SearchAPI. This option is intended for dev/test purposes.
    :param output: SearchAPI output format, can be used to alter what metadata is returned and the structure of the results.

    :return: Dictionary of search results
    """

    return asf_search.search(product_list=product_list, host=host, output=output)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="asf_search",
    version="0.1.0",
    author="Alaska Satellite Facility Discovery Team",
    author_email="uaf-asf-discovery@alaska.edu",
    description="Python wrapper for ASF's SearchAPI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/asfadmin/Discovery-asf_search.git",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    #test_suite='???',
    #tests_require=['???'],
    python_requires='>=3.6',
    install_requires=[
        'requests==2.25.1'
    ]
)
